class AddUserIdToDiaries < ActiveRecord::Migration[5.2]
  # changeメソッド以外に、up/downメソッドというものがある
  # upで実際に変更されるものを定義。downはrollback用のもの。
  # downも書いて元に戻るようにしておかないと、正しくrollbackが出来なくなってしまうの注意
  # changeメソッドはupの内容だけ書いておけば、勝手にrollback時にdownで本来書いておく処理を推測して実行してくれる
  # 但し、changeではrollback出来ないケースもあるので注意
  # http://tanihiro.hatenablog.com/entry/2014/01/10/182122
  # 今回は外部キーとしてuser_idをDiariesテーブルに持たせるだけなのでchangeでもいい

  def up
    execute 'DELETE FROM diaries;'
    # add_reference テーブル名, リファレンス名 [, オプション]
    add_reference :diaries, :user, foreign_key: true, null: false, index: true
  end

  def down
    remove_foreign_key :diaries, :users
    # remove_reference テーブル名, リファレンス名 [, オプション]
    remove_reference :diaries, :user, index: true
  end

  # def change
  #   execute 'DELETE FROM diaries;'
  #   add_column :diaries, :user, null: false, index: true
  # end
end
